<?php
/*
Plugin Name: Blix Archive
Plugin URI: http://rmarsh.com/plugins/blix-archive/
Description: Displays a neat monthly archive in the style ofthe Blix theme.
Version: 1.0.0
Author: Rob Marsh, SJ
Author URI: http://rmarsh.com/
*/

/*
	This is almost entirely the work of Sebastian Schmieg (http://www.kingcosmonaut.de/)
	from his popular theme Blix. I have adapted it to work under WordPress 2.1, made it into 
	a plugin and  made the plugin cache-ready.
*/

/*
Copyright 2006  Rob Marsh, SJ  (http://rmarsh.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
	Display the monthly archive of posts in a neat list, e.g.,
	
		January 2007
		A Wonderful Post
		Another Post
		
		December 2006
		An Older Post
		...
	
	The month is a link to the month's archive and is wrapped with the $before and $after tags 
	(<h3> and </h3>, by default). Each month's posts are shown as an unordered list with the class
	specified by $listclass' (postspermonth'by default).
	
	An optional count of a post's comments can be included via $show_comment_count.
	
	If my Post Output Plugin is installed the Blix Archive output will be cached for efficiency.
	
*/
function blix_archive($show_comment_count=false, $before='<h3>', $after='</h3>', $listclass='postspermonth') {
 	$result = false;
	// if the Plugin Output Cache is installed we can cheat...
	if (defined('POC_CACHE')) {
		$key = 'b_a'.$before.$after.$listclass;
		$cache = new POC_Cache();
		$cache->timer_start();
		$result = $cache->fetch($key);
		if ($result) $cache_time = sprintf('<!-- Compact Archive took %.3f seconds from the cache -->', $cache->timer_stop());
	}
	// ... otherwise we do it the hard way
	if (false === $result) {
		$result = get_blix_archive($show_comment_count, $before, $after, $listclass);
		if (defined('POC_CACHE')) $cache->store($key, $result);
	} 
	echo $result;
	if (defined('POC_CACHE')) echo $cache_time;
}

/********************************************************************************************************
	Stuff below this point is not meant to be used directly
*********************************************************************************************************/

function get_blix_archive($show_comment_count, $before, $after, $listclass) {
	global $month, $wpdb;
	$result = '';
	$below21 = version_compare($wp_version, '2.1','<');
	// WP 2.1 changed the way post_status and post_type fields work
	if ($below21) {
		$now        = current_time('mysql');
		$arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS year, MONTH(post_date) AS month, count(ID) as posts FROM " . $wpdb->posts . " WHERE post_date <'" . $now . "' AND post_status='publish' AND post_password='' GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date DESC");
	} else {
		$arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(post_date) AS year, MONTH(post_date) AS month, count(ID) as posts FROM " . $wpdb->posts . " WHERE post_type='post' AND post_status='publish' AND post_password='' GROUP BY YEAR(post_date), MONTH(post_date) ORDER BY post_date DESC");
	}
	if ($arcresults) {
		foreach ($arcresults as $arcresult) {
			$url  = get_month_link($arcresult->year, $arcresult->month);
    		$text = sprintf('%s %d', $month[zeroise($arcresult->month,2)], $arcresult->year);
    		$result .= get_archives_link($url, $text, '', $before, $after);

			$thismonth   = zeroise($arcresult->month,2);
			$thisyear = $arcresult->year;
			if ($below21) {
				$arcresults2 = $wpdb->get_results("SELECT ID, post_date, post_title, comment_status FROM " . $wpdb->posts . " WHERE post_date LIKE '$thisyear-$thismonth-%' AND post_status='publish' AND post_password='' ORDER BY post_date DESC");
			} else {
				$arcresults2 = $wpdb->get_results("SELECT ID, post_date, post_title, comment_status FROM " . $wpdb->posts . " WHERE post_date LIKE '$thisyear-$thismonth-%' AND post_status='publish' AND post_type='post' AND post_password='' ORDER BY post_date DESC");
			}
        	if ($arcresults2) {
        		$result .= "<ul class=\"$listclass\">\n";
            	foreach ($arcresults2 as $arcresult2) {
               		if ($arcresult2->post_date != '0000-00-00 00:00:00') {
                 		$url       = get_permalink($arcresult2->ID);
                 		$arc_title = $arcresult2->post_title;

                 		if ($arc_title) $text = strip_tags($arc_title);
                    	else $text = $arcresult2->ID;

                   		$result .= "<li>".get_archives_link($url, $text, '');
						if ($show_comment_count) {
							$comments = mysql_query("SELECT comment_ID FROM " . $wpdb->comments . " WHERE comment_post_ID=" . $arcresult2->ID);
							$comments_count = mysql_num_rows($comments);
							if ($arcresult2->comment_status == "open" OR $comments_count > 0) $result .= '&nbsp;('.$comments_count.')';
						}
						$result .= "</li>\n";
                 	}
            	}
            	$result .= "</ul>\n";
        	}
		}
	}
	return $result;
}

?>